from wexample_wex_core.const.globals import CORE_COMMAND_NAME

APP_DIR_APP_DATA_NAME: str = f".{CORE_COMMAND_NAME}"
APP_ENV_DEV: str = "dev"
APP_ENV_LOCAL: str = "local"
APP_ENV_PROD: str = "prod"
APP_ENV_TEST: str = "test"
APP_FILE_APP_CONFIG: str = "config.yml"
APP_FILE_APP_ENV: str = ".env"



from typing import TypedDict, Optional, List, Dict

from wexample_helpers.const.types import StringKeysDict


class AppConfig(TypedDict):
    branch: Optional[str]
    domain_main: str
    domain_tld: str
    domains: List[str]
    domains_string: str
    env: StringKeysDict
    name: str
    host: Dict[str, str]
    password: Dict[str, str]
    path: Dict[str, str]
    server: StringKeysDict
    service: StringKeysDict
    started: bool
    user: Dict[str, str | int]
